View Source Kinda.RootVerifier (kinda v0.11.0)
Verifies the root kinda repo, including bundled example surfaces.
Summary
Types
@type command_runner() :: module()
Verifies the root kinda repo, including bundled example surfaces.
@type command_runner() :: module()