View Source Kinda.Wrapper.CField (kinda v0.11.0)
Normalized C field fact extracted from a record declaration.
Summary
Types
@type t() :: %Kinda.Wrapper.CField{ ctype: Kinda.Wrapper.CType.t() | nil, name: String.t() }
Normalized C field fact extracted from a record declaration.
@type t() :: %Kinda.Wrapper.CField{ ctype: Kinda.Wrapper.CType.t() | nil, name: String.t() }