View Source Kinda.Wrapper.Extract (kinda v0.11.0)
Extracts a normalized wrapper manifest from a Clang AST tree.
Summary
Functions
@spec from_clang_ast(map() | list()) :: Kinda.Wrapper.Manifest.t()
Extracts a normalized wrapper manifest from a Clang AST tree.
@spec from_clang_ast(map() | list()) :: Kinda.Wrapper.Manifest.t()